@@ -110,7 +110,7 @@ class App:
 
         await response(scope, recieve, send)
 
-    def __call__(self, scope, recieve, send):
+    async def __call__(self, scope, recieve, send):
         path_info = scope["path"]
 
         # if path_info.startswith("/static") or path_info.startswith("static"):
