@@ -1,13 +1,15 @@
-from webob import Request
+from starlette.requests import Request
 
 class Middleware:
     def __init__(self, app):
         self.app = app
     
-    def __call__(self, environ, start_response):
-        request = Request(environ)
+    async def __call__(self, scope, receive, send):
+        request = Request(scope=scope, receive=receive)
+        
         response = self.app.handle_request(request)
-        return response(environ, start_response)
+        
+        await response(scope, receive, send)
 
     def add(self, middleware_cls):
         self.app = middleware_cls(self.app)
@@ -25,3 +27,5 @@ class Middleware:
         self.process_response(request, response)
 
         return response
+
+
